// This extension was developed by :
// * Mark Bokil http://markbokil.com
// * http://markbokil.com/downloads/extensions/
// version: 1.0.2
// date: 9-2-12
// License: GPLv2+

const St = imports.gi.St;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Util = imports.misc.util;
const Main = imports.ui.main;
const Lang = imports.lang;
const GLib = imports.gi.GLib;
const Shell = imports.gi.Shell;
const Gettext = imports.gettext.domain('markbokil.com-extensions');
const _ = Gettext.gettext;
const ExtensionsPath = GLib.build_filenamev([global.userdatadir, 'extensions/']);

const DEBUG = false;


function ExtensionsShortcuts(metadata)
{	

	this._init();
}

function debug(str) {
    if (DEBUG) {
        str = "[ Extension Shortcuts ]--------> " + str;
        global.log(str);
    }
}

ExtensionsShortcuts.prototype =
{
	__proto__: PanelMenu.Button.prototype,
	
    	_init: function(gicon) 
    	{			
		PanelMenu.Button.prototype._init.call(this, St.Align.START);

		this._iconActor = new St.Icon({ icon_name: 'preferences-other-symbolic',
                                   		icon_type: St.IconType.SYMBOLIC,
                                        style_class: 'system-status-icon' });

        this.actor.add_actor(this._iconActor); 
		this._iconActor.get_parent().add_style_class_name("panelButtonWidth");
			
		this._buildMenu();
	},
	
	_buildMenu: function()
	{    			
		this.ie = new PopupMenu.PopupMenuItem("Installed Extensions");
		this.menu.addMenuItem(this.ie);
		this.ie.connect('activate', Lang.bind(this, this._doLocalExtensions));

		this.ae = new PopupMenu.PopupMenuItem("Browse Extensions");
		this.menu.addMenuItem(this.ae);
		this.ae.connect('activate', Lang.bind(this, this._doAllExtensions));

		this.pf = new PopupMenu.PopupMenuItem("Extension Preferences");
		this.menu.addMenuItem(this.pf);
		this.pf.connect('activate', Lang.bind(this, this._doExtensionPreferences));

		this.gt = new PopupMenu.PopupMenuItem("Advanced Settings");
		this.menu.addMenuItem(this.gt);
		this.gt.connect('activate', Lang.bind(this, this._doTweakTool));


		this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());

		this.ef = new PopupMenu.PopupMenuItem("Open Extensions Folder");
		this.menu.addMenuItem(this.ef);
		this.ef.connect('activate', Lang.bind(this, this._doLocalFolder));

		this.rs = new PopupMenu.PopupMenuItem("Restart Shell");
		this.menu.addMenuItem(this.rs);
		this.rs.connect('activate', Lang.bind(this, this._restartShell));
	},

	_doLocalExtensions: function() {
		Main.Util.trySpawnCommandLine('xdg-open https://extensions.gnome.org/local/');
	},

	_doAllExtensions: function() {
		Main.Util.trySpawnCommandLine('xdg-open https://extensions.gnome.org/');
	},

	_doLocalFolder: function() {
		Main.Util.trySpawnCommandLine('xdg-open ' + ExtensionsPath);
	},

	_doExtensionPreferences: function() {
		Main.Util.trySpawnCommandLine('gnome-shell-extension-prefs');
	},

	_doTweakTool: function() {
		try {
			Main.Util.trySpawnCommandLine('gnome-tweak-tool');
		} catch(e) {
			Main.notify('Gnome-tweak-tool is required. Install it to access advanced settings.');
			debug('_doTweakTool: gnome-tweak-tool missing');
		}
	},

	_restartShell: function() {
		global.reexec_self();
	},


	enable: function()
	{
		Main.panel._rightBox.insert_child_at_index(this.actor, 0);
		Main.panel._menus.addMenu(this.menu);
	},

	disable: function()
	{
		Main.panel._menus.removeMenu(this.menu);
		Main.panel._rightBox.remove_actor(this.actor);
	}
}
	
function init(metadata) 
{		
	return new ExtensionsShortcuts(metadata);
}
